==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/photos/l10n/de_DE.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotos",
    "Your memories under your control" : "Ihre Erinnerungen unter Ihrer Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Kollaborative Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit Ihnen geteilt",
    "Tags" : "Schlagwörter",
    "Locations" : "Orte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus den Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Go back to the previous view." : "Zur vorherigen Ansicht zurückgehen.",
    "Back" : "Zurück",
    "Go to the add collaborators view." : "Zur Ansicht Mitbearbeitende hinzufügen wechseln.",
    "Add collaborators" : "Mitarbeitende hinzufügen",
    "Save." : "Speichern.",
    "Create the album." : "Das Album erstellen.",
    "Save" : "Speichern",
    "Create album" : "Erstelle Album",
    "Back to the new album form." : "Zurück zur neuen Albumform.",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {ablumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Create a new album." : "Ein neues Album erstellen.",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Stück","%n Fotos und Videos"],
    "_Share with %n user_::_Share with %n users_" : ["Mit %n Nutzer teilen","Mit %n Nutzern teilen"],
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die Ihr Album bearbeiten können",
    "Search for collaborators" : "Suche nach Mitbearbeitenden",
    "Search people or groups" : "Suchen nach Personen oder Gruppen",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} zur Liste der Mitarbeitenden hinzufügen",
    "No collaborators available" : "Keine Mitarbeitenden verfügbar",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Public link copied!" : "Öffentlicher Link kopiert!",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Share via public link" : "Als öffentlichen Link teilen",
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "The file is in the favorites" : "Die Datei befindet sich in den Favoriten",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "Open the \"{name}\" sub-directory" : "Öffne den Unterordner \"{name}\" ",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
    "Select the default location for your media" : "Standardspeicherort für Ihre Medien auswählen",
    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
    "View" : "Ansicht",
    "Photos directory" : "Fotoverzeichnis",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Add photos to the album" : "Fotos zum Album hinzufügen",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person verbinden",
    "Download selected photos" : "Ausgwählte Fotos herunterladen",
    "Favorite" : "Favorisieren",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Merge person" : "Person zusammenführen",
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe Ihrer Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Ordner werden geladen...",
    "No photos in here" : "Keine Fotos vorhanden",
    "Shared albums" : "Geteilte Alben",
    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Schlagworten werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagworte",
    "Add" : "Hinzufügen",
    "Create a new album" : "Neues Album erstellen",
    "Add selection to an album" : "Auswahl einem Album hinzufügen",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "Failed to fetch faces list." : "Gesichter-Liste konnte nicht geladen werden.",
    "All your media" : "Alle Ihre Medien",
    "Tagged photos" : "Fotos mit Schlagworten",
    "Failed to create {albumName}." : "{albumName} konnte nicht erstellt werden.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} konnte nicht in {newAlbumName} umbenannt werden.",
    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
    "Your photos" : "Ihre Fotos",
    "Your videos" : "Ihre Videos",
    "Your folders" : "Ihre Ordner",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/photos/l10n/de_DE.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "Your memories under your control" : "Ihre Erinnerungen unter Ihrer Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Kollaborative Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit Ihnen geteilt",
    "Tags" : "Schlagwörter",
    "Locations" : "Orte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus den Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Go back to the previous view." : "Zur vorherigen Ansicht zurückgehen.",
    "Back" : "Zurück",
    "Go to the add collaborators view." : "Zur Ansicht Mitbearbeitende hinzufügen wechseln.",
    "Add collaborators" : "Mitarbeitende hinzufügen",
    "Save." : "Speichern.",
    "Create the album." : "Das Album erstellen.",
    "Save" : "Speichern",
    "Create album" : "Erstelle Album",
    "Back to the new album form." : "Zurück zur neuen Albumform.",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {albumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Create a new album." : "Ein neues Album erstellen.",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Stück","%n Fotos und Videos"],
    "_Share with %n user_::_Share with %n users_" : ["Mit %n Nutzer teilen","Mit %n Nutzern teilen"],
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die Ihr Album bearbeiten können",
    "Search for collaborators" : "Suche nach Mitbearbeitenden",
    "Search people or groups" : "Suchen nach Personen oder Gruppen",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} zur Liste der Mitarbeitenden hinzufügen",
    "No collaborators available" : "Keine Mitarbeitenden verfügbar",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert!",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to fetch album." : "Album konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "The file is in the favorites" : "Die Datei befindet sich in den Favoriten",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "Open the \"{name}\" sub-directory" : "Öffne den Unterordner \"{name}\" ",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
    "Select the default location for your media" : "Standardspeicherort für Ihre Medien auswählen",
    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
    "View" : "Ansicht",
    "Photos directory" : "Fotoverzeichnis",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Add photos to the album" : "Fotos zum Album hinzufügen",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgwählte Fotos herunterladen",
    "Favorite" : "Favorisieren",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Merge person" : "Person zusammenführen",
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe Ihrer Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Ordner werden geladen...",
    "No photos in here" : "Keine Fotos vorhanden",
    "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
    "Shared albums" : "Geteilte Alben",
    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Schlagworten werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagworte",
    "Add" : "Hinzufügen",
    "Create a new album" : "Neues Album erstellen",
    "Add selection to an album" : "Auswahl einem Album hinzufügen",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "Failed to fetch faces list." : "Gesichter-Liste konnte nicht geladen werden.",
    "All your media" : "Alle Ihre Medien",
    "Tagged photos" : "Fotos mit Schlagworten",
    "Failed to create {albumName}." : "{albumName} konnte nicht erstellt werden.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} konnte nicht in {newAlbumName} umbenannt werden.",
    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
    "Your photos" : "Ihre Fotos",
    "Your videos" : "Ihre Videos",
    "Your folders" : "Ihre Ordner",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");
